Kayrock.CreateTopics.V2.Request (kayrock v1.0.0)

Copy Markdown View Source

Kayrock-generated request struct for Kafka create_topics v2 API messages

The schema of this API is

[
  topics: {:array,
   [
     name: :string,
     num_partitions: :int32,
     replication_factor: :int16,
     assignments: {:array,
      [partition_index: :int32, broker_ids: {:array, :int32}]},
     configs: {:array, [name: :string, value: :nullable_string]}
   ]},
  timeout_ms: :int32,
  validate_only: :boolean
]

Summary

Types

t()

Request struct for the Kafka create_topics API v2

Functions

Returns the Kafka API key for this API

Returns the API version (2) implemented by this module

Returns a function that can be used to deserialize the wire response from the broker for this message type

Returns the schema of this message

Serialize a message to binary data for transfer to a Kafka broker

Types

t()

@type t() :: %Kayrock.CreateTopics.V2.Request{
  client_id: nil | binary(),
  correlation_id: nil | integer(),
  timeout_ms: nil | integer(),
  topics: [
    %{
      name: nil | binary(),
      num_partitions: nil | integer(),
      replication_factor: nil | integer(),
      assignments: [
        %{partition_index: nil | integer(), broker_ids: [nil | integer()]}
      ],
      configs: [%{name: nil | binary(), value: nil | binary()}]
    }
  ],
  validate_only: nil | integer()
}

Request struct for the Kafka create_topics API v2

Functions

api_key()

@spec api_key() :: integer()

Returns the Kafka API key for this API

api_vsn()

@spec api_vsn() :: integer()

Returns the API version (2) implemented by this module

response_deserializer()

@spec response_deserializer() :: (binary() ->
                              {Kayrock.CreateTopics.V2.Response.t(), binary()})

Returns a function that can be used to deserialize the wire response from the broker for this message type

schema()

@spec schema() :: term()

Returns the schema of this message

See above.

serialize(struct)

@spec serialize(t()) :: iodata()

Serialize a message to binary data for transfer to a Kafka broker