Mix task to generate the .ex files for each of the kafka protocol messages
Summary
Functions
Callback implementation for Mix.Task.run/1.
Functions
Callback implementation for Mix.Task.run/1.
Mix task to generate the .ex files for each of the kafka protocol messages
Callback implementation for Mix.Task.run/1.
Callback implementation for Mix.Task.run/1.